==> skill-core-1.12.5-sources.jar: com/ptteng/common/skill/service/UserArticleRelationService.java <==
package com.ptteng.common.skill.service;

import com.gemantic.common.exception.ServiceDaoException;
import com.gemantic.common.exception.ServiceException;
import com.ptteng.common.dao.BaseDaoService;
import com.ptteng.common.skill.model.UserArticleRelation;
import org.osoa.sca.annotations.Remotable;

import java.util.List;

@Remotable
public interface UserArticleRelationService extends BaseDaoService {

	



   		   
		
		public Long insert(UserArticleRelation userArticleRelation)throws ServiceException, ServiceDaoException;
		  
    	   
		
		public List<UserArticleRelation> insertList(List<UserArticleRelation> userArticleRelationList)throws ServiceException, ServiceDaoException;
		  
    	   
		
		public boolean delete(Long id)throws ServiceException, ServiceDaoException;
		  
    	   
		
		public boolean update(UserArticleRelation userArticleRelation)throws ServiceException, ServiceDaoException;
		  
    	   
		
		public boolean updateList(List<UserArticleRelation> userArticleRelationList)throws ServiceException, ServiceDaoException;
		  
    	   
		
		public UserArticleRelation getObjectById(Long id)throws ServiceException, ServiceDaoException;
		  
    	   
		
		public List<UserArticleRelation> getObjectsByIds(List<Long> ids)throws ServiceException, ServiceDaoException;
		  
    	
	


			
			
	/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	public Integer  countUserArticleRelationIdsByUidAndTypeAndWhether(Long uid, Integer type, Integer whether)throws ServiceException, ServiceDaoException;
			
			
	/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	public Integer  countUserArticleRelationIdsByAidAndTypeAndWhether(Long aid, Integer type, Integer whether)throws ServiceException, ServiceDaoException;
					
			
	/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	public Long  getUserArticleRelationIdByUidAndAidAndType(Long uid, Long aid, Integer type)throws ServiceException, ServiceDaoException;
	public Long  getUserArticleRelationIdByUidAndAidAndTypeAndWeather(Long uid, Long aid, Integer type,Integer weather)throws ServiceException, ServiceDaoException;


	/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	public List<Long>  getUserArticleRelationIdsByUidAndTypeAndWhether(Long uid, Integer type, Integer whether, Integer start, Integer limit)throws ServiceException, ServiceDaoException;
			
			
	/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	public List<Long>  getUserArticleRelationIdsByAidAndTypeAndWhether(Long aid, Integer type, Integer whether, Integer start, Integer limit)throws ServiceException, ServiceDaoException;
		
	
	
	
	/**
	 * 
	 * @param
	 * @return
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	public List<Long> getUserArticleRelationIds(Integer start, Integer limit)
			throws ServiceException, ServiceDaoException;

	/**
	 * 
	 * @param
	 * @return
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	public Integer countUserArticleRelationIds() throws ServiceException, ServiceDaoException;
	

}

==> skill-core-30.0.0-sources.jar: com/ptteng/common/skill/service/UserArticleRelationService.java <==
package com.ptteng.common.skill.service;

import com.gemantic.common.exception.ServiceDaoException;
import com.gemantic.common.exception.ServiceException;
import com.ptteng.common.dao.BaseDaoService;
import com.ptteng.common.skill.model.UserArticleRelation;
import org.osoa.sca.annotations.Remotable;

import java.util.List;

@Remotable
public interface UserArticleRelationService extends BaseDaoService {

	



   		   
		
		public Long insert(UserArticleRelation userArticleRelation)throws ServiceException, ServiceDaoException;
		  
    	   
		
		public List<UserArticleRelation> insertList(List<UserArticleRelation> userArticleRelationList)throws ServiceException, ServiceDaoException;
		  
    	   
		
		public boolean delete(Long id)throws ServiceException, ServiceDaoException;
		  
    	   
		
		public boolean update(UserArticleRelation userArticleRelation)throws ServiceException, ServiceDaoException;
		  
    	   
		
		public boolean updateList(List<UserArticleRelation> userArticleRelationList)throws ServiceException, ServiceDaoException;
		  
    	   
		
		public UserArticleRelation getObjectById(Long id)throws ServiceException, ServiceDaoException;
		  
    	   
		
		public List<UserArticleRelation> getObjectsByIds(List<Long> ids)throws ServiceException, ServiceDaoException;
		  
    	
	


			
			
	/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	public Integer  countUserArticleRelationIdsByUidAndTypeAndWhether(Long uid, Integer type, Integer whether)throws ServiceException, ServiceDaoException;
			
			
	/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	public Integer  countUserArticleRelationIdsByAidAndTypeAndWhether(Long aid, Integer type, Integer whether)throws ServiceException, ServiceDaoException;
					
			
	/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	public Long  getUserArticleRelationIdByUidAndAidAndTypeAndTargetType(Long uid, Long aid, Integer type,Integer targetType)throws ServiceException, ServiceDaoException;
	public Long  getUserArticleRelationIdByUidAndAidAndTypeAndWeather(Long uid, Long aid, Integer type,Integer weather)throws ServiceException, ServiceDaoException;


	/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	public List<Long>  getUserArticleRelationIdsByUidAndTypeAndWhether(Long uid, Integer type, Integer whether, Integer start, Integer limit)throws ServiceException, ServiceDaoException;
			
			
	/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	public List<Long>  getUserArticleRelationIdsByAidAndTypeAndWhether(Long aid, Integer type, Integer whether, Integer start, Integer limit)throws ServiceException, ServiceDaoException;
		
	
	
	
	/**
	 * 
	 * @param
	 * @return
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	public List<Long> getUserArticleRelationIds(Integer start, Integer limit)
			throws ServiceException, ServiceDaoException;

	/**
	 * 
	 * @param
	 * @return
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	public Integer countUserArticleRelationIds() throws ServiceException, ServiceDaoException;
	

}
